.. _api:
  
Python API
==========

.. note::

   This API documentation covers {kiwi} |version|

.. toctree::
   :maxdepth: 1

   api/kiwi
   api/kiwi.archive
   api/kiwi.boot.image
   api/kiwi.bootloader.config
   api/kiwi.bootloader.install
   api/kiwi.bootloader
   api/kiwi.bootloader.template
   api/kiwi.boot
   api/kiwi.builder
   api/kiwi.container
   api/kiwi.container.setup
   api/kiwi.filesystem
   api/kiwi.iso_tools
   api/kiwi.package_manager
   api/kiwi.partitioner
   api/kiwi.repository
   api/kiwi.repository.template
   api/kiwi.solver.repository
   api/kiwi.solver
   api/kiwi.storage
   api/kiwi.storage.subformat
   api/kiwi.storage.subformat.template
   api/kiwi.system
   api/kiwi.tasks
   api/kiwi.utils
   api/kiwi.volume_manager
